@@ -1,14 +1,8 @@
 # -*- coding: utf-8 -*-
-'''stuf has attributes'''
+'''stuf has attributes.'''
 
 from stuf.core import defaultstuf, fixedstuf, frozenstuf, orderedstuf, stuf
 
-__version__ = (0, 8, 22)
+__version__ = (0, 9, 1)
 
 __all__ = 'defaultstuf fixedstuf frozenstuf orderedstuf stuf'.split()
-
-idefaultstuf = defaultstuf
-ifixedstuf = fixedstuf
-ifrozenstuf = frozenstuf
-iorderedstuf = orderedstuf
-istuf = stuf
